@@ -3,7 +3,7 @@ package Fey::DBIManager;
 use strict;
 use warnings;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Fey::Exceptions qw( object_state_error param_error );
 use Scalar::Util qw( blessed );
@@ -19,7 +19,7 @@ has _sources =>
       is        => 'ro',
       isa       => 'HashRef[Fey::DBIManager::Source]',
       default   => sub { {} },
-      init_arg  => "\0_sources",
+      init_arg  => undef,
       provides  => { get    => 'get_source',
                      set    => 'add_source',
                      delete => 'remove_source',
