@@ -77,22 +77,19 @@ has '_threaded' =>
       isa      => 'Bool',
       lazy     => 1,
       default  => sub { threads->can('tid') ? 1 : 0 },
-      # a hack to make this attribute hard to set via the constructor
-      init_arg => "\0_threaded",
+      init_arg => undef,
     );
 
 has '_pid' =>
     ( is       => 'rw',
       isa      => 'Num',
-      # a hack to make this attribute hard to set via the constructor
-      init_arg => "\0_pid",
+      init_arg => undef,
     );
 
 has '_tid' =>
     ( is       => 'rw',
       isa      => 'Num',
-      # a hack to make this attribute hard to set via the constructor
-      init_arg => "\0_tid",
+      init_arg => undef,
     );
 
 use DBI;
@@ -165,8 +162,8 @@ sub _check_nested_transactions
         {
             # This error comes from DBI in its default implementation
             # of begin_work(). There didn't seem to be a way to shut
-            # this off (PrintWarn does not help). Hopefully the
-            # message text won't change.
+            # this off (setting PrintWarn to false does not do
+            # it). Hopefully the message text won't change.
             local $SIG{__WARN__}
                 = sub { warn @_ unless $_[0] =~ /Already in a transaction/ };
 
